pub struct MatchingStatus { /* private fields */ }Expand description
A struct that indicates if there exist entities matching the key expression.
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let publisher = session.declare_publisher("key/expression").await.unwrap();
let matching_status = publisher.matching_status().await.unwrap();Implementations
Sourceimpl MatchingStatus
impl MatchingStatus
Sourcepub fn matching(&self) -> bool
pub fn matching(&self) -> bool
Returns true if there exist entities matching the target (i.e., either Subscribers matching Publisher’s key expression or Queryables matching Querier’s key expression and target).
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let publisher = session.declare_publisher("key/expression").await.unwrap();
let matching_subscribers: bool = publisher
.matching_status()
.await
.unwrap()
.matching();Trait Implementations
Sourceimpl Clone for MatchingStatus
impl Clone for MatchingStatus
Sourcefn clone(&self) -> MatchingStatus
fn clone(&self) -> MatchingStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchingStatus
impl Debug for MatchingStatus
impl Copy for MatchingStatus