#[non_exhaustive]pub struct Subscriber<Handler> { /* private fields */ }Expand description
A subscriber that provides data through a Handler.
Subscribers can be created from a zenoh Session
with the declare_subscriber function.
Callback subscribers will run in background until the session is closed, or until it is undeclared. On the other hand, subscribers with a handler are automatically undeclared when dropped.
Examples
Using callback:
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
session
.declare_subscriber("key/expression")
.callback(|sample| { println!("Received: {} {:?}", sample.key_expr(), sample.payload()) })
.await
.unwrap();
// subscriber run in background until the session is closedUsing channel handler:
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let subscriber = session
.declare_subscriber("key/expression")
.with(flume::bounded(32))
.await
.unwrap();
while let Ok(sample) = subscriber.recv_async().await {
println!("Received: {} {:?}", sample.key_expr(), sample.payload());
}
// subscriber is undeclared at the end of the scopeImplementations
Sourceimpl<Handler> Subscriber<Handler>
impl<Handler> Subscriber<Handler>
Sourcepub fn id(&self) -> EntityGlobalId
Available on crate feature unstable only.
pub fn id(&self) -> EntityGlobalId
unstable only.Returns the EntityGlobalId of this Subscriber.
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let subscriber = session.declare_subscriber("key/expression")
.await
.unwrap();
let subscriber_id = subscriber.id();Sourcepub fn handler(&self) -> &Handler
pub fn handler(&self) -> &Handler
Returns a reference to this subscriber’s handler.
An handler is anything that implements crate::handlers::IntoHandler.
The default handler is crate::handlers::DefaultHandler.
Sourcepub fn handler_mut(&mut self) -> &mut Handler
pub fn handler_mut(&mut self) -> &mut Handler
Returns a mutable reference to this subscriber’s handler.
An handler is anything that implements crate::handlers::IntoHandler.
The default handler is crate::handlers::DefaultHandler.
Sourcepub fn undeclare(self) -> SubscriberUndeclaration<Handler>where
Handler: Send,
pub fn undeclare(self) -> SubscriberUndeclaration<Handler>where
Handler: Send,
Undeclare the Subscriber.
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let subscriber = session.declare_subscriber("key/expression")
.await
.unwrap();
subscriber.undeclare().await.unwrap();Trait Implementations
Sourceimpl<Handler: Debug> Debug for Subscriber<Handler>
impl<Handler: Debug> Debug for Subscriber<Handler>
Sourceimpl<Handler> DerefMut for Subscriber<Handler>
impl<Handler> DerefMut for Subscriber<Handler>
Sourceimpl<Handler> Drop for Subscriber<Handler>
impl<Handler> Drop for Subscriber<Handler>