Module query

Query/reply primitives

The Queryable instance is declared by a Session::declare_queryable method. It is requested by a Session::get operation which receives data in Reply structures.

Structs

Parameters
A map of key/value (String,String) parameters. It can be parsed from a String, using ; or <newline> as separator between each parameters and = as separator between a key and its value. Keys and values are trimmed.
Querierunstable
A querier that allows to send queries to a queryable.
QuerierBuilderunstable
A builder for initializing a querier.
QuerierGetBuilderunstable
A builder for initializing a query to be sent from the querier.
Query
Structs received by a Queryable.
QueryConsolidation
The replies consolidation strategy to apply on replies to a get.
Queryable
A queryable that provides data through a Handler.
QueryableBuilder
A builder for initializing a Queryable.
QueryableUndeclaration
A Resolvable returned when undeclaring a queryable.
Reply
Struct returned by a get.
ReplyBuilder
A builder returned by Query::reply() and Query::reply_del()
ReplyBuilderDelete
ReplyBuilderPut
ReplyErrBuilder
A builder returned by Query::reply_err().
ReplyError
Error returned by a get.
Selector
A selector is the combination of a Key Expression, which defines the set of keys that are relevant to an operation, and a set of parameters with a few intended uses:
TimeRangeunstable
The structural representation of the Zenoh Time DSL, which may adopt one of two syntax:

Enums

ConsolidationMode
The kind of consolidation to apply to a query.
QueryTarget
The Queryables that should be target of a get.
ReplyKeyExprunstable
The kind of accepted query replies.
TimeBoundunstable
TimeExprunstable

Traits

ZenohParametersunstable
The trait allows to set/read parameters processed by the zenoh library itself