QuerierUndeclaration

Struct QuerierUndeclaration 

pub struct QuerierUndeclaration<'a> { /* private fields */ }
A Resolvable returned when undeclaring a querier.

Examples


let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let querier = session.declare_querier("key/expression").await.unwrap();
querier.undeclare().await.unwrap();

Implementations

Source

impl<'a> QuerierUndeclaration<'a>

pub fn wait_callbacks(self) -> Self

Available on crate feature unstable only.

Block in undeclare operation until all currently running instances of reply and matching listeners’ callbacks (if any) return.

This API has been marked as unstable: it works as advertised, but it may be changed in a future release.