Struct QueryableBuilder

pub struct QueryableBuilder<'a, 'b, Handler, const BACKGROUND: bool = false> { /* private fields */ }
A builder for initializing a Queryable.

Examples


let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let queryable = session.declare_queryable("key/expression").await.unwrap();

Implementations

Source

impl<'a, 'b> QueryableBuilder<'a, 'b, DefaultHandler>

pub fn callback<F>( self, callback: F, ) -> QueryableBuilder<'a, 'b, Callback<Query>>
where F: Fn(Query) + Send + Sync + 'static,

Receive the queries for this queryable with a callback.

Examples

let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let queryable = session
    .declare_queryable("key/expression")
    .callback(|query| {println!(">> Handling query '{}'", query.selector());})
    .await
    .unwrap();
pub fn callback_mut<F>( self, callback: F, ) -> QueryableBuilder<'a, 'b, Callback<Query>>
where F: FnMut(Query) + Send + Sync + 'static,

Receive the queries for this Queryable with a mutable callback.

Using this guarantees that your callback will never be called concurrently. If your callback is also accepted by the callback method, we suggest you use it instead of callback_mut.

Examples

let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let mut n = 0;
let queryable = session
    .declare_queryable("key/expression")
    .callback_mut(move |query| {n += 1;})
    .await
    .unwrap();
pub fn with<Handler>( self, handler: Handler, ) -> QueryableBuilder<'a, 'b, Handler>
where Handler: IntoHandler<Query>,

Receive the queries for this Queryable with a Handler.

Examples

let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let queryable = session
    .declare_queryable("key/expression")
    .with(flume::bounded(32))
    .await
    .unwrap();
while let Ok(query) = queryable.recv_async().await {
    println!(">> Handling query '{}'", query.selector());
}
Source

impl<'a, 'b> QueryableBuilder<'a, 'b, Callback<Query>>

pub fn background(self) -> QueryableBuilder<'a, 'b, Callback<Query>, true>

Register the queryable callback to be run in background until the session is closed.

Background builder doesn’t return a Queryable object anymore.

Examples

let session = zenoh::open(zenoh::Config::default()).await.unwrap();
// no need to assign and keep a variable with a background queryable
session
    .declare_queryable("key/expression")
    .callback(|query| {println!(">> Handling query '{}'", query.selector());})
    .background()
    .await
    .unwrap();
Source

impl<Handler, const BACKGROUND: bool> QueryableBuilder<'_, '_, Handler, BACKGROUND>

pub fn complete(self, complete: bool) -> Self

Change queryable completeness.

pub fn allowed_origin(self, origin: Locality) -> Self

Available on crate feature unstable only.
This API has been marked as unstable: it works as advertised, but it may be changed in a future release.

Restrict the matching queries that will be receive by this Queryable to the ones that have the given Locality.