Module sample

Sample primitives

The Sample structure is the data unit received from Subscriber or Queryable instances. It contains the payload and all the metadata associated with the data.

Structs

Sample
A zenoh sample.
SampleBuilder
SampleBuilderAny
SampleBuilderDelete
SampleBuilderPut
SampleFields
Structure with public fields for sample. It’s convenient if it’s necessary to decompose a sample into its fields.
SourceInfounstable
Information on the source of a zenoh Sample.

Enums

Localityunstable
The locality of samples to be received by subscribers or targeted by publishers.
SampleKind
The kind of a Sample.

Type Aliases

SourceSnunstable
The sequence number of the Sample from the source.