#[non_exhaustive]pub struct Sample { /* private fields */ }Expand description
The Sample structure is the data unit received
by Subscriber or Querier
or Session::get.
It contains the payload and all metadata associated with the data.
Implementations
Sourceimpl Sample
impl Sample
Sourcepub fn key_expr(&self) -> &KeyExpr<'static>
pub fn key_expr(&self) -> &KeyExpr<'static>
Gets the key expression on which this Sample was published.
Sourcepub fn payload_mut(&mut self) -> &mut ZBytes
pub fn payload_mut(&mut self) -> &mut ZBytes
Gets the payload of this Sample.
Sourcepub fn kind(&self) -> SampleKind
pub fn kind(&self) -> SampleKind
Gets the kind of this Sample.
Sourcepub fn congestion_control(&self) -> CongestionControl
pub fn congestion_control(&self) -> CongestionControl
Gets the congestion control of this Sample.
Sourcepub fn reliability(&self) -> Reliability
Available on crate feature unstable only.
pub fn reliability(&self) -> Reliability
unstable only.Gets the reliability of this Sample.
This API has been marked as unstable: it works as advertised, but it may be changed in a future release.
Sourcepub fn express(&self) -> bool
pub fn express(&self) -> bool
Gets the express flag value. If true, the message is not batched during transmission, in order to reduce latency.
Sourcepub fn source_info(&self) -> Option<&SourceInfo>
Available on crate feature unstable only.
pub fn source_info(&self) -> Option<&SourceInfo>
unstable only.Gets info on the source of this Sample.
This API has been marked as unstable: it works as advertised, but it may be changed in a future release.
Sourcepub fn attachment(&self) -> Option<&ZBytes>
pub fn attachment(&self) -> Option<&ZBytes>
Gets the sample attachment: a map of key-value pairs, where each key and each value is a byte-slice.
Sourcepub fn attachment_mut(&mut self) -> Option<&mut ZBytes>
pub fn attachment_mut(&mut self) -> Option<&mut ZBytes>
Gets the sample attachment: a map of key-value pairs, where each key and each value is a byte-slice.