LinksBuilder

Struct LinksBuilder 

pub struct LinksBuilder<'a> { /* private fields */ }
Available on crate feature unstable only.
A builder returned by SessionInfo::links().

This API has been marked as unstable: it works as advertised, but it may be changed in a future release.

The builder creates an iterator over the established Links within the session. Multiple Link can be established between two zenoh nodes within the same Transport. By default all links are returned, but you can filter them by transport using the transport() method.

Examples

let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let links = session.info().links().await;
for link in links {
    println!("Link: {} -> {}", link.src(), link.dst());
}

Implementations

Source

impl<'a> LinksBuilder<'a>

pub fn transport(self, transport: Transport) -> Self

Filter links by transport.

Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let transports = session.info().transports().await;
if let Some(transport) = transports.into_iter().next() {
    let links = session.info().links().transport(transport).await;
    for link in links {
        println!("Link: {} -> {}", link.src(), link.dst());
    }
}