Payload primitives
The ZBytes type is Zenoh’s representation of raw byte data.
It provides mechanisms for zero-copy creation and access (From<Vec<u8>> and
ZBytes::slices), as well as methods for sequential
reading/writing (ZBytes::reader, ZBytes::writer).
Thezenoh_ext crate provides serialization and deserialization of basic types and structures for ZBytes
z_serialize /
z_deserialize.
Structs
- Encoding
- Default encoding values used by Zenoh.
- OptionZ
Bytes - Wrapper type for API ergonomicity to allow any type
Tto be converted intoOption<ZBytes>whereTimplementsInto<ZBytes>. - ZBytes
- ZBytes contains the serialized bytes of user data.
- ZBytes
Reader - A reader that implements
std::io::Readtrait to deserialize from aZBytes. - ZBytes
Slice Iterator - An iterator to iterate on raw bytes slices contained in a
ZBytes. - ZBytes
Writer - A writer that implements
std::io::Writetrait to serialize into aZBytes.