Query/reply primitives
The Queryable instance is declared by a
Session::declare_queryable method.
It is requested by a Session::get operation which
receives data in Reply structures.
Structs
- Parameters
- A map of key/value (String,String) parameters.
It can be parsed from a String, using
;or<newline>as separator between each parameters and=as separator between a key and its value. Keys and values are trimmed. - Querier
unstable - A querier that allows to send queries to a queryable.
- Querier
Builder unstable - A builder for initializing a
querier. - Querier
GetBuilder unstable - A builder for initializing a
queryto be sent from the querier. - Query
- Structs received by a
Queryable. - Query
Consolidation - The replies consolidation strategy to apply on replies to a
get. - Queryable
- A queryable that provides data through a
Handler. - Queryable
Builder - A builder for initializing a
Queryable. - Queryable
Undeclaration - A
Resolvablereturned when undeclaring a queryable. - Reply
- Struct returned by a
get. - Reply
Builder - A builder returned by
Query::reply()andQuery::reply_del() - Reply
Builder Delete - Reply
Builder Put - Reply
ErrBuilder - A builder returned by
Query::reply_err(). - Reply
Error - Error returned by a
get. - Selector
- A selector is the combination of a Key Expression, which defines the set of keys that are relevant to an operation, and a set of parameters with a few intended uses:
- Time
Range unstable - The structural representation of the Zenoh Time DSL, which may adopt one of two syntax:
Enums
- Consolidation
Mode - The kind of consolidation to apply to a query.
- Query
Target - The
Queryables that should be target of aget. - Reply
KeyExpr unstable - The kind of accepted query replies.
- Time
Bound unstable - Time
Expr unstable
Traits
- Zenoh
Parameters unstable - The trait allows to set/read parameters processed by the zenoh library itself