Sample primitives
The Sample structure is the data unit received from Subscriber
or Queryable instances. It contains the payload and all the metadata associated with the data.
Structs
- Sample
- A zenoh sample.
- Sample
Builder - Sample
Builder Any - Sample
Builder Delete - Sample
Builder Put - Sample
Fields - Structure with public fields for sample. It’s convenient if it’s necessary to decompose a sample into its fields.
- Source
Info unstable - Information on the source of a zenoh
Sample.
Enums
- Locality
unstable - The locality of samples to be received by subscribers or targeted by publishers.
- Sample
Kind - The kind of a
Sample.