pub struct LinksBuilder<'a> { /* private fields */ }Available on crate feature
unstable only.Expand description
A builder returned by SessionInfo::links().
This API has been marked as unstable: it works as advertised, but it may be changed in a future release.
The builder creates an iterator over the established Links
within the session.
Multiple Link can be established between two zenoh nodes within
the same Transport.
By default all links are returned, but you can filter them by transport using
the transport() method.
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let links = session.info().links().await;
for link in links {
println!("Link: {} -> {}", link.src(), link.dst());
}Implementations
Sourceimpl<'a> LinksBuilder<'a>
impl<'a> LinksBuilder<'a>
Sourcepub fn transport(self, transport: Transport) -> Self
pub fn transport(self, transport: Transport) -> Self
Filter links by transport.
Examples
let session = zenoh::open(zenoh::Config::default()).await.unwrap();
let transports = session.info().transports().await;
if let Some(transport) = transports.into_iter().next() {
let links = session.info().links().transport(transport).await;
for link in links {
println!("Link: {} -> {}", link.src(), link.dst());
}
}Trait Implementations
Sourceimpl IntoFuture for LinksBuilder<'_>
impl IntoFuture for LinksBuilder<'_>
Sourcetype Output = <LinksBuilder<'_> as Resolvable>::To
type Output = <LinksBuilder<'_> as Resolvable>::To
The output that the future will produce on completion.
Sourcetype IntoFuture = Ready<<LinksBuilder<'_> as Resolvable>::To>
type IntoFuture = Ready<<LinksBuilder<'_> as Resolvable>::To>
Which kind of future are we turning this into?
Sourcefn into_future(self) -> Self::IntoFuture
fn into_future(self) -> Self::IntoFuture
Creates a future from a value. Read more
Sourceimpl Resolvable for LinksBuilder<'_>
impl Resolvable for LinksBuilder<'_>